@@ -3,4 +3,4 @@ from pydraw.util import *;
 from pydraw.color import Color;
 from pydraw.location import Location;
 from pydraw.screen import Screen;
-from pydraw.objects import Object, Renderable, CustomRenderable, Rectangle, Oval, Triangle, Polygon, CustomPolygon, Image, Text, Line;
+from pydraw.objects import *;
